"use strict";

/* eslint-disable no-console */

import React, { useMemo } from 'react';
import { Platform, ScrollView, StyleSheet, Text, View } from 'react-native';
import { processTokens } from 'src/syntax/highlighter';
import { useSyntaxHighlighter } from '../../hooks/useSyntaxHighlighter';
import { jsx as _jsx } from "react/jsx-runtime";
const monospaceFont = Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
function transformThemeToStyles(theme) {
  const defaultBackground = theme.colors?.['editor.background'];
  const foreground = theme.colors?.['editor.foreground'];
  console.log('[SyntaxHighlighter] Theme colors:', {
    background: defaultBackground,
    foreground,
    allColors: theme.colors
  });
  const styles = StyleSheet.create({
    scrollView: {
      flex: 1,
      minHeight: 20
    },
    codeContainer: {
      padding: 16,
      minWidth: '100%'
    },
    lineContainer: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    baseToken: {
      fontFamily: monospaceFont
    }
  });
  const colorStyles = new Map();
  return {
    base: styles,
    background: defaultBackground,
    getTokenStyle: token => {
      const key = `${token.color || ''}-${token.fontStyle || ''}`;
      if (!colorStyles.has(key)) {
        const style = {
          color: token.color || foreground,
          fontStyle: token.fontStyle ? 'italic' : 'normal',
          fontWeight: token.fontStyle ? 'bold' : 'normal'
        };
        console.log('[SyntaxHighlighter] Created new token style:', {
          key,
          token,
          style
        });
        colorStyles.set(key, style);
      }
      return colorStyles.get(key);
    }
  };
}
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const {
    tokens: rawTokens
  } = useSyntaxHighlighter({
    text,
    language,
    languageId: languageId || String(language),
    theme
  });
  const tokens = useMemo(() => rawTokens.map(line => processTokens(line)), [rawTokens]);
  console.log('[SyntaxHighlighter] Processed tokens:', tokens);
  const styles = useMemo(() => transformThemeToStyles(theme), [theme]);
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.base.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.base.codeContainer, {
      backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
    }, scrollViewProps?.contentContainerStyle, containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((line, rowIndex) => /*#__PURE__*/_jsx(View, {
        style: [styles.base.lineContainer, {
          backgroundColor: theme.colors?.['editor.background'] || '#1e1e1e'
        }],
        children: line.map((token, tokenIndex) => {
          const tokenStyle = styles.getTokenStyle(token);
          if (rowIndex === 0 && tokenIndex === 0) {
            console.log('[SyntaxHighlighter] First token styles:', {
              base: styles.base.baseToken,
              token: tokenStyle,
              fontSize,
              custom: textStyle
            });
          }
          return /*#__PURE__*/_jsx(Text, {
            style: [styles.base.baseToken, tokenStyle, {
              fontSize
            }, textStyle],
            children: token.content
          }, `${rowIndex}-${tokenIndex}`);
        })
      }, rowIndex))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map